chicken_turtle_project package
==============================

Submodules
----------

chicken_turtle_project.common module
------------------------------------

.. automodule:: chicken_turtle_project.common
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.mkdoc module
-----------------------------------

.. automodule:: chicken_turtle_project.mkdoc
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.mkproject module
---------------------------------------

.. automodule:: chicken_turtle_project.mkproject
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.mkvenv module
------------------------------------

.. automodule:: chicken_turtle_project.mkvenv
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.pre_commit_hook module
---------------------------------------------

.. automodule:: chicken_turtle_project.pre_commit_hook
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.release module
-------------------------------------

.. automodule:: chicken_turtle_project.release
    :members:
    :undoc-members:
    :show-inheritance:

chicken_turtle_project.specification module
-------------------------------------------

.. automodule:: chicken_turtle_project.specification
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: chicken_turtle_project
    :members:
    :undoc-members:
    :show-inheritance:
